

## .env configuration
- [ ] merge existing files such `.env` from `.env.example`


## Development Tools

Use the following tools for development when applicable:

- [ ] `docker-compose`
- [ ] `uv`
- [ ] `cargo`

## Testing Tools

Use the following tools for testing when applicable:

- [ ] `cargo test`
- [ ] `uv test`
- [ ] `docker-compose test`

## Documentation Tools

Use the following tools for documentation when applicable:

- [ ] `cargo doc`
- [ ] `uv doc`
- [ ] `docker-compose doc`

## Deployment Tools

Use the following tools for deployment when applicable:

- [ ] `docker-compose up`
- [ ] `uv deploy`
- [ ] `cargo deploy`

## Continuous Integration Tools

Use the following tools for continuous integration when applicable:

- [ ] `docker-compose ci`
- [ ] `uv ci`
- [ ] `cargo ci`

## Continuous Deployment Tools

Use the following tools for continuous deployment when applicable:

- [ ] `docker-compose cd`
- [ ] `uv cd`
- [ ] `cargo cd`

## Monitoring Tools

Use the following tools for monitoring when applicable:

- [ ] `docker-compose monitor`
- [ ] `uv monitor`
- [ ] `cargo monitor`

## Logging Tools

Use the following tools for logging when applicable:

- [ ] `docker-compose log`
- [ ] `uv log`
- [ ] `cargo log`

## Security Tools

Use the following tools for security when applicable:

- [ ] `docker-compose security`
- [ ] `uv security`
- [ ] `cargo security`

## Backup Tools

Use the following tools for backup when applicable:

- [ ] `docker-compose backup`
- [ ] `uv backup`
- [ ] `cargo backup`

## Restore Tools

Use the following tools for restore when applicable:

- [ ] `docker-compose restore`
- [ ] `uv restore`
- [ ] `cargo restore`
